[llvm] r196172 - Debug Info: rename getDebugInfoVersionFromModule to getDebugMetadataVersionFromModule.

Manman Ren manman.ren at gmail.com
Mon Dec 2 16:12:14 PST 2013


Author: mren
Date: Mon Dec  2 18:12:14 2013
New Revision: 196172

URL: http://llvm.org/viewvc/llvm-project?rev=196172&view=rev
Log:
Debug Info: rename getDebugInfoVersionFromModule to getDebugMetadataVersionFromModule.

Suggested by Eric.

Modified:
    llvm/trunk/include/llvm/DebugInfo.h
    llvm/trunk/lib/IR/AutoUpgrade.cpp
    llvm/trunk/lib/IR/DebugInfo.cpp

Modified: llvm/trunk/include/llvm/DebugInfo.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/DebugInfo.h?rev=196172&r1=196171&r2=196172&view=diff
==============================================================================
--- llvm/trunk/lib/IR/AutoUpgrade.cpp (original)
+++ llvm/trunk/lib/IR/AutoUpgrade.cpp Mon Dec  2 18:12:14 2013
@@ -494,7 +494,7 @@ Value *llvm::UpgradeBitCastExpr(unsigned
 /// Check the debug info version number, if it is out-dated, drop the debug
 /// info. Return true if module is modified.
 bool llvm::UpgradeDebugInfo(Module &M) {
-  if (getDebugInfoVersionFromModule(M) == DEBUG_METADATA_VERSION)
+  if (getDebugMetadataVersionFromModule(M) == DEBUG_METADATA_VERSION)
     return false;
 
   return StripDebugInfo(M);

Modified: llvm/trunk/lib/IR/DebugInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/IR/DebugInfo.cpp?rev=196172&r1=196171&r2=196172&view=diff
==============================================================================
--- llvm/trunk/include/llvm/DebugInfo.h (original)
+++ llvm/trunk/include/llvm/DebugInfo.h Mon Dec  2 18:12:14 2013
@@ -759,8 +759,8 @@ DITypeIdentifierMap generateDITypeIdenti
 /// Return true if module is modified.
 bool StripDebugInfo(Module &M);
 
-/// Return Debug Info Version by checking module flags.
-unsigned getDebugInfoVersionFromModule(const Module &M);
+/// Return Debug Info Metadata Version by checking module flags.
+unsigned getDebugMetadataVersionFromModule(const Module &M);
 
 /// DebugInfoFinder tries to list all debug info MDNodes used in a module. To
 /// list debug info MDNodes used by an instruction, DebugInfoFinder uses

Modified: llvm/trunk/lib/IR/AutoUpgrade.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/IR/AutoUpgrade.cpp?rev=196172&r1=196171&r2=196172&view=diff
==============================================================================
--- llvm/trunk/lib/IR/DebugInfo.cpp (original)
+++ llvm/trunk/lib/IR/DebugInfo.cpp Mon Dec  2 18:12:14 2013
@@ -1478,8 +1478,8 @@ bool llvm::StripDebugInfo(Module &M) {
   return Changed;
 }
 
-/// Return Debug Info Version by checking module flags.
-unsigned llvm::getDebugInfoVersionFromModule(const Module &M) {
+/// Return Debug Info Metadata Version by checking module flags.
+unsigned llvm::getDebugMetadataVersionFromModule(const Module &M) {
   Value *Val = M.getModuleFlag("Debug Info Version");
   if (!Val)
     return 0;





More information about the llvm-commits mailing list